@@ -1,6 +1,6 @@
-/* $Id: session.c 4782 2005-01-22 17:55:32Z benny $ */
+/* $Id: session.c 21496 2006-05-04 22:12:21Z benny $ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,10 @@
 #include <string.h>
 #endif
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
+
 #include <libxfce4mcs/mcs-manager.h>
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
@@ -302,7 +306,6 @@ static void
 dialog_run (McsPlugin *plugin)
 {
   GtkWidget *notebook;
-  GtkWidget *header;
   GtkWidget *label;
   GtkWidget *page;
   GtkWidget *dbox;
@@ -318,22 +321,21 @@ dialog_run (McsPlugin *plugin)
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
   kiosk = xfce_kiosk_new ("xfce4-session");
-  kiosk_can_chooser = xfce_kiosk_query (kiosk, "Chooser");
-  kiosk_can_logout = xfce_kiosk_query (kiosk, "Logout");
-  kiosk_can_compat = xfce_kiosk_query (kiosk, "Compatibility");
-  kiosk_can_security = xfce_kiosk_query (kiosk, "Security");
+  kiosk_can_chooser = xfce_kiosk_query (kiosk, "Chooser") || xfce_kiosk_query (kiosk, "CustomizeChooser");
+  kiosk_can_logout = xfce_kiosk_query (kiosk, "Logout") || xfce_kiosk_query (kiosk, "CustomizeLogout");
+  kiosk_can_compat = xfce_kiosk_query (kiosk, "Compatibility") || xfce_kiosk_query (kiosk, "CustomizeCompatibility");
+  kiosk_can_security = xfce_kiosk_query (kiosk, "Security") || xfce_kiosk_query (kiosk, "CustomizeSecurity");
   xfce_kiosk_free (kiosk);
   tooltips = gtk_tooltips_new ();
 
   rc = config_open (TRUE);
 
-  dialog = gtk_dialog_new_with_buttons (_("Sessions and Startup"),
-                                        NULL,
-                                        GTK_DIALOG_NO_SEPARATOR,
-                                        GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
-                                        NULL);
-
-  gtk_window_set_icon (GTK_WINDOW (dialog), plugin->icon);
+  dialog = xfce_titled_dialog_new_with_buttons (_("Sessions and Startup"),
+                                                NULL,
+                                                GTK_DIALOG_NO_SEPARATOR,
+                                                GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+                                                NULL);
+  gtk_window_set_icon_name (GTK_WINDOW (dialog), "xfce4-session");
 
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (dialog_response), NULL);
@@ -342,10 +344,6 @@ dialog_run (McsPlugin *plugin)
 
   dbox = GTK_DIALOG (dialog)->vbox;
 
-  header = xfce_create_header (plugin->icon, _("Sessions and Startup"));
-  gtk_box_pack_start (GTK_BOX (dbox), header, FALSE, TRUE, 0);
-  gtk_widget_show (header);
-
   notebook = gtk_notebook_new ();
   gtk_box_pack_start (GTK_BOX (dbox), notebook, TRUE, TRUE, 0);
   gtk_widget_show (notebook);
@@ -380,9 +378,12 @@ mcs_plugin_init (McsPlugin *plugin)
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
   plugin->plugin_name = g_strdup ("session");
-  plugin->caption = g_strdup (_("Sessions and Startup"));
+  /* the button label in the xfce-mcs-manager dialog */
+  plugin->caption = g_strdup (Q_("Button Label|Sessions and Startup"));
   plugin->run_dialog = dialog_run;
   plugin->icon = xfce_themed_icon_load ("xfce4-session", 48);
+  if (G_LIKELY (plugin->icon != NULL))
+    g_object_set_data_full (G_OBJECT (plugin->icon), "mcs-plugin-icon-name", g_strdup ("xfce4-session"), g_free);
 
   return MCS_PLUGIN_INIT_OK;
 }
